@@ -1,8 +1,6 @@
-`rank.shape` <-
-function(X,init=NULL,steps=Inf,eps=1e-6,maxiter=100,na.action=na.fail)
-{
- X<-na.action(X)
- if(!all(sapply(X, is.numeric))) stop("'X' must be numeric")
+`rank.shape` <- function(X, init=NULL, steps=Inf, eps=1e-6, maxiter=100, na.action=na.fail)
+{ 
+ X <- na.action(X)
  X<-as.matrix(X) 
 
  p<-dim(X)[2]
